*****************.
* This SPSS syntax generates key tables from the ICVS main database (2007 version), these tables were used for the last two reports 
* with key findings. The syntax is alsmost ready for use, you will need to study the codebook that came with
* the database, in particular the identification variables (countries, years, national or main city).

*references:
*Van Dijk, J.J.M., van Kesteren, J.N. & Smit, P. (2008). Criminal Victimisation in International Perspective, Key findings from the 2004-2005 ICVS and EU ICS. Den Haag: Boom Juridische Uitgevers. 
*Van Kesteren, J.N., Mayhew, P. & Nieuwbeerta, P. (2000). Criminal Victimisation in Seventeen Industrialised Countries: Key-findings from the 2000 international Crime Victims Survey. The Hague: Ministry of Justice, WODC.
*Van Kesteren, J.N. (2007). Integrated Database from the International Crime Victims Survey (ICVS) 1989-20

* This syntax first does some data manipulation and then generates an aggregated database.
* Second, the syntax generates tables
* This syntax is valid for both the national surveys and the main city surveys
*
* 1. Just before the aggregate command, activate the weighting variable
*     w005b for the national survey and w004a for the main city surveys
* 2. First line of the aggregate command, use I005b for the national surveys and I004a for teh main city surveys
*     also use I002 (year of the survey) or I0021 or I002b for sweep 1 to 5
* 3. In the table commands, use I005b for the national surveys and I004a for the main city surveys
*     also use I002 (year of the survey) or I0021 or I002b for sweep 1 to 5
*
***********John van Kesteren****vanKest@UvT.nl*****.


get file 'C:\Data\icvs\data\2005database\ICVS2005_2.SAV'.

******victim support and useful******.
count rap=c06b400 c09b400 c11b400 c12b400 (1).
count rapb=c06b400 c09b400 c11b400 c12b400 (1 2 3).

count vs=c06b700 c09b700 c11b700 c12b700 (1).
count vsb=c06b700 c09b700 c11b700 c12b700 (1,2,3).
count vu=c06b801 c09b801 c11b801 c12b801 (2).
count vub=c06b801 c09b801 c11b801 c12b801 (1,2,3).

*weight by w005b or w004a,
*use identification variable I005b or I004a

weight by w00b5.
aggregate outfile * / break i005b i002b
 /rap=sum(rap)
 /rapb=sum(rapb)
 /vs=sum(vs)
 /vsb=sum(vsb)
 /vu=sum(vu)
 /vub=sum(vub).

******victim support****.
compute report=100*rap/rapb.
compute vicsup=100*vs/vsb.
compute supuse=100*vu/vub.

****computing pick up rate****.
do if (vs > 0 and vu>0).
compute pickup=vs*100 / (vs+vu).
variable labels pickup 'victim support pickup rate'. 
if (vu=0 or vs=0)pickup=-1.
recode pickup (-1=sysmiss).
compute pickb=vs+vu.
end if.
format report vicsup supuse pickup rapb vsb vub pickb (f5.0).
variable labels 
 report 'reporting 4 crimes'
 vicsup 'victim support 4 crimes'
 supuse 'victim support would have been useful'
 pickup 'victim support pickup rate'
 vsb'N'  vub'N'  rapb 'N'  pickb 'N'.

recode i002b (5.1=5).

tables
 /observation  vicsup supuse report pickup rapb vsb vub pickb
 /table i005b by i002b > (report + rapb)    /title = 'report'
 /footer 'asutralia one crime less'
 /table i005b by i002b > (vicsup + vsb)   /title = 'vicsup'
 /footer 'asutralia one crime less'
 /table i005b by i002b > (supuse + vub)  /title = 'supuse'
 /footer 'australia one crime less'
 /table i005b by i002b > (pickup + pickb)   /title = 'pickup rate'
 /footer 'asutralia one crime less'.