*****************.
* This SPSS syntax generates key tables from the ICVS main database (2007 version), these tables were used for the last two reports 
* with key findings. The syntax is alsmost ready for use, you will need to study the codebook that came with
* the database, in particular the identification variables (countries, years, national or main city).

*references:
*Van Dijk, J.J.M., van Kesteren, J.N. & Smit, P. (2008). Criminal Victimisation in International Perspective, Key findings from the 2004-2005 ICVS and EU ICS. Den Haag: Boom Juridische Uitgevers. 
*Van Kesteren, J.N., Mayhew, P. & Nieuwbeerta, P. (2000). Criminal Victimisation in Seventeen Industrialised Countries: Key-findings from the 2000 international Crime Victims Survey. The Hague: Ministry of Justice, WODC.
*Van Kesteren, J.N. (2007). Integrated Database from the International Crime Victims Survey (ICVS) 1989-2005, codebook and data. Tilburg: INTERVICT Universiteit van Tilburg 


* This syntax first does some data manipulation and then generates an aggregated database.
* Second, the syntax generates tables from these aggregated files
* This syntax is valid for both the national surveys and the main city surveys
*
Note this
* 1. Just before the aggregate command, activate the weighting variable
*     w005b for the national survey and w004a for the main city surveys
* 2. First line of the aggregate command, use I005b for the national surveys and I004a for teh main city surveys
*     also use I002 (year of the survey) or I0021 or I002b for sweep 1 to 5
* 3. In the table commands, use I005b for the national surveys and I004a for the main city surveys
*     also use I002 (year of the survey) or I002 or I002b for sweep 1 to 5
*
***********John van Kesteren****vanKest@UvT.nl*****.

get file 'C:\Data\icvs\data\2005database\ICVS2005_2.SAV'.

recode c01a200 c02a200 c03a200 c04a200 c05a200 c06a200 c07a200 c09a200 
 c10a200 c11a200 c12a200 (sysmiss -1=0)(1 6 99=100)(2=200)(3=300)(4=400)(5=500).

*crosstabs k040 by c11a000 C11A100 c11a200.

recode c12e010 (0=sysmiss).

*freq k040.

*freq c11a100 c11a000 c11a200 c11e010 K040.
DO if (k040=1).
compute c11a10m=c11a100.
compute c11a00m=c11a000.
compute c11a20m=c11a200.
compute c11e01m=c11e010.
recode c11a100 c11a000 c11a200 c11e010 (-1 thru 99=sysmiss).
END if.

count vic10= c01a100 c02a100 c04a100 c05a100 c06a100 c07a100 c09a100 c10a100 c11a100 c12a100 (2).
recode vic10 (1 thru 9=2).
count vic09= c01a100 c02a100 c04a100 c06a100 c07a100 c09a100 c10a100 c11a100 c12a100 (2).
recode vic09 (1 thru 9=2).

count v10a000 = c01a000 c02a000 c04a000 c05a000 c06a000 c07a000 c09a000 c10a000 c11a000 c12a000 (1).
compute v10a200 = sum (c01a200,c02a200,c04a200,c05a200,c06a200,c07a200,c09a200,c10a200,c11a200,c12a200).
*freq v10a000 v10a200.

if (c11a100=2 and c11e010 le 3) c11ass=2.
if (c12a100=2 and c12e010 = 2) c12ass=2.
recode c11ass c12ass (sysmiss=0).
count contact= c09a100 c11ass c12ass (2).
count prop = c01a100 c02a100 c04a100 c05a100 c06a100 c07a100 c10a100 (2).

*australia, overall victimisation* does not include sexual offences.
do if (i005b=30 and i002b=5).
compute v10a000=-1.
compute v10a200=-1.
compute contact=-1.
end if.


*peru, overall victimisation and assault*.
do if  (i005a=405).
compute vic10=-1.
compute vic09=-1.
compute c12a100=-2.
compute contact=-1.
end if.

recode vic10 vic09 c12a100 contact (-1 -2=sysmis).
recode i002b (5.1=5).
value labels i002b 0 '0'.

*select if (i002 ge 2001).
*weight by w005b.
*aggregate outfile * / break i005b i002a
*weight by w004a.
*aggregate outfile * / break i004a i002a

weight by w005b.
aggregate outfile * / break i005b i002a
 /vic10=pin(vic10,2,2)
 /vic09=pin(vic09,2,2)
 /contact=pin(contact,1,4)
 /prop = pin (prop, 1,9)
 /c01a100 'cartheft' =pin (c01a100,2,2)
 /c01c101 'return' = fin (c01c101,1,1)
 /c02a100 'theft from car' =pin (c02a100,2,2)
 /c03a100 'car vandalism' = pin (c03a100,2,2)
 /c04a100 'motorcycle theft' =pin (c04a100,2,2)
 /c05a100 'bicycle theft' =pin (c05a100,2,2)
 /c06a100 'burglary' =pin (c06a100,2,2)
 /c07a100 'attempted burglary' =pin (c07a100,2,2)
 /c08a100 'theft from sheds' = pin (c08a100,2,2)
 /c09a100 'robbery' =pin (c09a100,2,2)
 /c10a100 'theft of personal property' =pin (c10a100,2,2)
 /c11a100 'sexual offences' =pin (c11a100,2,2)
 /c11a10m 'sexual offences MEN' =pin(c11a10m,2,2)
 /c12a100 'assault & threat' =pin (c12a100,2,2)
 /c10c201 'pick?' =fin(c10c201,1,1)
 /c11e010 'sexass?' =fin(c11e010,1,3)
 /c11e01m 'sexass?M' =fin(c11e01m,1,3)
 /c12e010 'ass' =fin(c12e010,2,2)
 /c13a100 'consum' =pin(c13a100,1,1)
 /c14a100 'bribery' =pin(c14a100,1,1)
 /k010 'carown' = pin(k010,1,1)
 /k020 'motorown' = pin (k020,1,1)
 /k030 'bicycleown' = pin (k030,1,1)
 /c01a000 '5y cartheft' = pin(c01a000,1,1)
 /c02a000 '5y theft from car' = pin(c02a000,1,1)
 /c03a000 '5y car vandalism' = pin(c03a000,1,1)
 /c04a000 '5y motorcycle theft' = pin(c04a000,1,1)
 /c05a000 '5y bicycle theft' = pin(c05a000,1,1)
 /c06a000 '5y burglary' = pin(c06a000,1,1)
 /c07a000 '5y attempted burglary' = pin(c07a000,1,1)
 /c09a000 '5y robbery' = pin(c09a000,1,1)
 /c10a000 '5y theft of personal property' = pin(c10a000,1,1)
 /c11a000 '5y sexual offences' = pin(c11a000,1,1)
 /c11a00m '5y sexual offences MEN' = pin(c11a00m,1,1)
 /c12a000 '5y assault & threat' = pin(c12a000,1,1)
 /v10a000 '5y ten crimes' = pin(v10a000,1,10)
 /c01a200 '1y incidents car theft' =mean(c01a200)
 /c02a200 '1y incidents theft from a car' =mean(c02a200)
 /c03a200 '1y incidents car vandalism' =mean(c03a200)
 /c04a200 '1y incidents motorcycle theft' =mean(c04a200)
 /c05a200 '1y incidents bicycle theft' =mean(c05a200)
 /c06a200 '1y incidents burglary' =mean(c06a200)
 /c07a200 '1y incidents attempted burglary' =mean(c07a200)
 /c09a200 '1y incidents robbery' =mean(c09a200)
 /c10a200 '1y incidents theft of personal property' =mean(c10a200)
 /c11a200 '1y incidents sexual offences' =mean(c11a200)
 /c11a20m '1y incidents sexual offences MEN' =mean(c11a20m)
 /c12a200 '1y incidents assault & threat' =mean(c12a200)
 /v10a200 '1y incidents ten crimes' =mean(v10a200).

tables
 /observation  vic10 vic09 c01a100 c02a100 c03a100 c04a100 c05a100
  c06a100 c07a100 c08a100 c09a100 c10a100 c11a100 c11a10m c12a100 
  v10a000 c01a000 c02a000 c03a000 c04a000 c05a000 c06a000 c07a000 c09a000 c10a000 c11a000 c11a00m c12a000
  v10a200 c01a200 c02a200 c03a200 c04a200 c05a200 c06a200 c07a200 c09a200 c10a200 c11a200 c11a20m c12a200
 /table i004a>i002a by vic10+c01a100+c02a100+c03a100+c04a100+c05a100+c06a100+c07a100+c09a100+c10a100+c11a100+c11a10m+c12a100 
 /table i004a>i002a by v10a000+c01a000+c02a000+c03a000+c04a000+c05a000+c06a000+c07a000+c09a000+c10a000+c11a000+c11a00m+c12a000 
 /table i004a>i002a by v10a200+c01a200+c02a200+c03a200+c04a200+c05a200+c06a200+c07a200+c09a200+c10a200+c11a200+c11a20m+c12a200 .

tables 
 /observation contact vic10
 /table i004a by i002a>vic10.

tables 
 /observation contact
 /table i004a by i002a>contact.

compute c01a102=c01a100*c01c101.
variable labels c01a102 'joyriding'.
compute c01a103=c01a100*(1-c01c101).
variable labels c01a103 'car was returned'.

compute c10a101=c10a100*c10c201.
variable labels c10a101 'pickpocketing'.

compute c11a101=c11a100*c11e010.
variable labels c11a101 'sexual assault'.

compute c11a101m=c11a10m*c11e01m.
variable labels  c11a101m 'sexaul assault MEN'.

compute c12a101=c12a100*c12e010.
variable labels  c12a101 'assault'.

tables 
 /observation c01a102 c10a101 c11a101 c11a101m c12a101 c13a100 c14a100 
 /table i005b > i002a by c01a102 + c10a101 + c11a101 + c11a101m + c12a101 + c13a100 + c14a100.

tables 
 /observation c01a102 c01a103
 /table i005b by i002a>c01a102 + i002a>c01a103.

tables 
 /observation c13a100 c14a100
 /table i004a by i002a>c13a100
 /table i004a by i002a>c14a100.

******owners*********.
compute c01a101=c01a100 * 100 / k010.
compute c02a101=c02a100 * 100 / k010.
compute c04a101=c04a100 * 100 / k020.
compute c05a101=c05a100 * 100 / k030.

tables
 /observation k010 c01a101 c02a101 k020 c04a101 k030 c05a101 c01a100 c02a100 c04a100 c05a100 
 /table i004a > i002a by k010 +c01a101 +c02a101 +k020 +c04a101 +k030 +c05a101.

tables
 /observation contact prop
 /table i004a by i002a>(prop + contact).